@@ -275,7 +275,13 @@ int process (jack_nframes_t nframes, void *arg){
         
 	info->inside = -3;                                        
         if (pthread_mutex_trylock (&info->mix_thread_lock)){
-/*		printf ("lock not possible \n");*/
+		/*printf ("lock not possible \n");*/
+		/* HIER STIMMT WAS NICHT */
+		pthread_cond_broadcast (&info->data_ready);
+        	info->inside = 2;
+        	pthread_mutex_unlock (&info->mix_thread_lock);
+        	info->inside = 3;
+
                 return 0;       
         }                               
                                 
@@ -296,8 +302,7 @@ int process (jack_nframes_t nframes, void *arg){
 	info->inside = -1; 
 	info->inrounds++;	
         info->last_nframes = nframes;
-       
-
+      
         if (info->submixes){ 
                 for (i = 0; i < info->nmixes;i++){
                         if (info->submixes[i]){
@@ -360,7 +365,7 @@ int process (jack_nframes_t nframes, void *arg){
                         }
                 }
         }
-/*       	pthread_cond_signal (&info->data_ready);*/
+       	/*pthread_cond_signal (&info->data_ready);*/
 	pthread_cond_broadcast (&info->data_ready);
 	info->inside = 2;
        	pthread_mutex_unlock (&info->mix_thread_lock);
@@ -389,16 +394,20 @@ static void* mix_thread(void *arg){
 	float* mainbufR = (float*) malloc(sizeof(float) * DEFAULT_RB_SIZE);
 	int cc = 0;
 	char *clientname = malloc(jack_client_name_size() * sizeof(char));
+	jack_status_t status;
 
         jack_set_error_function ((void*)errfunc);
 
         while (!info->jack_info->client && (cc < 99)){
 		memset(clientname,0,jack_client_name_size());
                 sprintf(clientname,"kluppe%d",++cc);
-                info->jack_info->client = jack_client_new (clientname);
+/*                info->jack_info->client = jack_client_new (clientname);*/
+		info->jack_info->client = jack_client_open (clientname, JackUseExactName,&status);
         }
 
+
         if (cc > 98){
+		fprintf (stderr, "jack_client_open() failed, status = 0x%2.0x\n", status);
                 fprintf (stderr, "jack server not running?\n");
                 info->jack_info->name = malloc(sizeof(char) * 10);
                 strncpy (info->jack_info->name,"nojack!",7);
@@ -434,6 +443,7 @@ static void* mix_thread(void *arg){
 /*	printf ("mixer thread:%d\n",(int)getpid());*/
 
 	while (1){
+/*		if (info->can_process == 2) printf ("status 2\n");*/
 		if ((info->can_process == 1) || (info->can_process == -1)){
 			info->can_process = 0;
 			info->jack_info->load = jack_cpu_load (info->jack_info->client);
@@ -493,6 +503,7 @@ static void* mix_thread(void *arg){
 					submix = submix_new (info,data->id,name);
 					/* connecting takes a while and can cause xruns */
 					/* LATER: move connecting to gui thread / looper.c */
+					printf ("connecting...\n");
 					if ((ports = jack_get_ports (info->jack_info->client, NULL, NULL, 
 						JackPortIsPhysical|JackPortIsOutput))){
 						if (jack_connect (info->jack_info->client,ports[0], 
@@ -670,7 +681,7 @@ static void* mix_thread(void *arg){
 		       	jack_ringbuffer_write (info->submixes[0]->rb_outR,(void *)mainbufR,info->last_nframes * info->sample_size);	
 			info->outside = 317;
 			info->can_process = 1;
-		}/* end if can_process*/
+		}/* end if can_process == 1 or -1*/
 		/* wait until process() signals more data */
 		++info->outrounds;
 		info->outside = 318;
@@ -736,6 +747,6 @@ jack_info_t* mixer_launch (speciallist_t *looperdatalist){
 		info->can_process = 1;
 		info->jack_info->alive = 1;
 	}
-
+	/* printf ("can process:%d, returning\n",info->can_process);*/ 
 	return info->jack_info;
 }
