@@ -611,8 +611,8 @@ static void looperdata_reset_grain (looper_data_t* data, int grain){
 	}
 
 	/* is it correct to multiply with speeds ? */
-	if ((*(data->grainfadelengths + grain) * *(data->grainspeeds + grain)) > 200) 
-						*(data->grainfadelengths + grain) = 200;
+	if ((*(data->grainfadelengths + grain) * *(data->grainspeeds + grain)) > 400) 
+						*(data->grainfadelengths + grain) = 400;
 	if (*(data->grainfadelengths + grain) < 5) *(data->grainfadelengths + grain) = 5;
 
 	/* pitch according to pitchmode: */
@@ -626,7 +626,9 @@ static void looperdata_reset_grain (looper_data_t* data, int grain){
 			if (data->grainpitchbend) 
 				*(data->grainspeeds + grain) *= data->grainpitchbend;
 			*(data->grainsactive + grain) = 1;
+/*			printf ("active grain %d\n",grain);*/
 		}else{
+/*			printf ("resetting grain %d\n",grain);*/
 			*(data->grainspeeds  + grain) = 1;
 			*(data->grainsactive + grain) = 0;	
 			*(data->grainpitchvolumes + grain) = 0.0;
@@ -716,12 +718,11 @@ void looperdata_set_grainpitchtablevalue ( looper_data_t* data, double value, do
 
 /*	printf ("set grainpitch:%lf - %lf\n",value,vol);*/
 	if (vol == 0.){
-/*		printf ("vol 0\n");*/
 		while (!found && (i < data->ngrains)){
 			if (*(data->grainpitchtable + i) == value){
 				if (data->grainpitchmode == GRAINPITCH_CHORD){
 					*(data->grainpitchtable + i) = 0.;
-/*					*(data->grainpitchvolumes + i) = 0.; */ /* mute  without fade !!!*/
+/*					*(data->grainpitchvolumes + i) = 0.; */  /* mute  without fade !!!*/
 				}else{
 				 	*(data->grainpitchtable + i) = 1.; /* fall back to regular volume */
 					*(data->grainpitchvolumes + i) = 0;
@@ -730,6 +731,7 @@ void looperdata_set_grainpitchtablevalue ( looper_data_t* data, double value, do
 			}
 			i++;
 		}		
+		if ((i == data->ngrains) && !found)printf ("off note not found!\n");
 	}else{
 		while (!found && (i < data->ngrains)){
 			if (data->grainpitchmode == GRAINPITCH_CHORD){
@@ -737,6 +739,7 @@ void looperdata_set_grainpitchtablevalue ( looper_data_t* data, double value, do
 /*				if (*(data->grainpitchtable + i) == 0.){*/
 					*(data->grainpitchtable + i) = value;
 					*(data->grainpitchvolumes + i) = vol;
+					*(data->grainsactive + i) = 1;
 					found++;
 				}
 			}else{
@@ -748,6 +751,7 @@ void looperdata_set_grainpitchtablevalue ( looper_data_t* data, double value, do
 			}
 			i++;
 		}
+		if ((i == data->ngrains) && !found)printf ("graintable full!\n");
 	}
 }
 
@@ -1613,5 +1617,10 @@ void looperdata_calc_sampleblock (looper_data_t* data, long size, float* Lbuf, f
 			data->recpos, rp, (data->recpos - rp), 
 			data->playpos, pp, (data->playpos - pp));
 */
+	} else {
+		for (l = 0;l < size;l++){
+			*(Lbuf + l) = 0.;
+			*(Rbuf + l) = 0.;
+		}
 	} /* end if active */
 }
